@@ -6,6 +6,7 @@
 
 
 #include "pengine.h"
+#include "physfs_utils.h"
 
 #ifdef WIN32
 #define WIN32_LEAN_AND_MEAN
@@ -136,7 +137,7 @@ int PApp::run(int argc, char *argv[])
   
   if (PHYSFS_init((argc >= 1) ? argv[0] : nullptr) == 0) {
     PUtil::outLog() << "PhysFS failed to initialise" << std::endl;
-    PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+    PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
     return 1;
   }
   
@@ -145,60 +146,31 @@ int PApp::run(int argc, char *argv[])
   {
     std::string lsdbuff;
     
-    lsdbuff = (std::string)PHYSFS_getUserDir();
+    lsdbuff = physfs_getDir();
     
-    // this is a hack because PhysFS doesn't appear to live
-    // up to its claim of creating the WriteDir if necessary.
-    // set write dir to home, create ~/.whatever, then change
-    // over to that dir.
-    
-#if 1
-    PUtil::outLog() << "Set writable user directory to \"" << lsdbuff << "\"" << std::endl;
+    PUtil::outLog() << "Setting writable user directory to \"" << lsdbuff << "\"" << std::endl;
     
     if (PHYSFS_setWriteDir(lsdbuff.c_str()) == 0) {
       PUtil::outLog() << "Failed to set PhysFS writable directory to \"" << lsdbuff << "\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
-    }
-    
-    if (PHYSFS_mkdir(appname.c_str()) == 0) {
-      PUtil::outLog() << "Failed to create directory \"" << appname << "\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
-    }
-#endif
-    
-    lsdbuff += appname;
-    
-    PUtil::outLog() << "Reset writable user directory to \"" << lsdbuff << "\"" << std::endl;
-    
-    if (PHYSFS_setWriteDir(lsdbuff.c_str()) == 0) {
-      PUtil::outLog() << "Failed to set PhysFS writable directory to \"" << lsdbuff << "\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+          << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
     
     if (PHYSFS_mkdir("/players") == 0)
     {
         PUtil::outLog() << "Failed to create directory \"/players\"" << std::endl
-            << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+            << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
     
-    // Adding "." to the search path seems to add more trouble than it's worth
-#if 0
-    if (PHYSFS_addToSearchPath(".", 1) == 0) {
-      PUtil::outLog() << "Failed to add PhysFS search directory \".\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
-    }
-#endif
-    
     std::string basedir = PHYSFS_getBaseDir();
     PUtil::outLog() << "Application base directory \"" << basedir << '\"' << std::endl;
-    if (PHYSFS_addToSearchPath(basedir.c_str(), 1) == 0) {
+    if (PHYSFS_mount(basedir.c_str(), NULL, 1) == 0) {
       PUtil::outLog() << "Failed to add PhysFS search directory \"" << basedir << "\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+          << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
     
-    if (PHYSFS_addToSearchPath(lsdbuff.c_str(), 1) == 0) {
+    if (PHYSFS_mount(lsdbuff.c_str(), NULL, 1) == 0) {
       PUtil::outLog() << "Failed to add PhysFS search directory \"" << lsdbuff << "\"" << std::endl
-          << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+          << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
 
     // we run MainApp::config() here in order to add data dirs to PhysFS search path
@@ -211,7 +183,9 @@ int PApp::run(int argc, char *argv[])
         PUtil::outLog() << "Config failed: " << e.what() << std::endl;
         
         if (PHYSFS_deinit() == 0)
-            PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+        {
+            PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
+        }
 
         return 1;
     }
@@ -220,30 +194,33 @@ int PApp::run(int argc, char *argv[])
     std::list<std::string> zipfiles = PUtil::findFiles("", ".zip");
     
     for (std::list<std::string>::iterator i = zipfiles.begin();
-      i != zipfiles.end(); i++) {
+      i != zipfiles.end(); ++i) {
       
       const char *realpath = PHYSFS_getRealDir(i->c_str());
       
       if (realpath) {
         std::string fullpath = (std::string)realpath + *i;
         
-        if (PHYSFS_addToSearchPath(fullpath.c_str(), 1) == 0) {
+        if (PHYSFS_mount(fullpath.c_str(), NULL, 1) == 0) {
           PUtil::outLog() << "Failed to add archive \"" << fullpath << "\"" << std::endl
-              << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+              << "PhysFS: " << physfs_getErrorString() << std::endl;
         }
       } else {
         PUtil::outLog() << "Failed to find path of archive \"" << *i << "\"" << std::endl
-            << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+            << "PhysFS: " << physfs_getErrorString() << std::endl;
       }
     }
   }
 
   srand(SDL_GetTicks());
   
-  SDL_WM_SetCaption(apptitle.c_str(), nullptr);
-  
   PUtil::outLog() << "Create window and set video mode" << std::endl;
-  
+#if 0
+    SDL_GL_SetAttribute(SDL_GL_CONTEXT_PROFILE_MASK, SDL_GL_CONTEXT_PROFILE_COMPATIBILITY);
+    SDL_GL_SetAttribute(SDL_GL_CONTEXT_MAJOR_VERSION, 2);
+    SDL_GL_SetAttribute(SDL_GL_CONTEXT_MINOR_VERSION, 0);
+    SDL_GL_SetAttribute(SDL_GL_ACCELERATED_VISUAL, 1);
+#endif
   SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
   
   if (reqRGB) {
@@ -268,11 +245,59 @@ int PApp::run(int argc, char *argv[])
   }
   
   if (cx <= 0 || cy <= 0) setScreenModeAutoWindow();
-  
-  screen = SDL_SetVideoMode(cx,cy,bpp,
-    SDL_OPENGL |
-    (fullscr ? SDL_FULLSCREEN : 0) |
-    (noframe ? SDL_NOFRAME : 0));
+
+    if (!autoVideo)
+    {
+        screen = SDL_CreateWindow(apptitle.c_str(),
+            SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED,
+            cx, cy,
+            SDL_WINDOW_OPENGL |
+            (fullscr ? SDL_WINDOW_FULLSCREEN : 0)
+            /* | (noframe ? SDL_NOFRAME : 0) */ ); // broken by SDL2, no more `SDL_NOFRAME`
+    }
+    else // automatic video mode
+    {
+        //
+        // NOTE:
+        //  The `SDL_GetDesktopMode()` function is used instead of the automatic
+        //  flag `SDL_WINDOW_FULLSCREEN_DESKTOP` because the latter fails to work
+        //  reliably on Linux in certain versions of SDL2.
+        //
+
+#define SDL_WINDOW_FULLSCREEN_DESKTOP_IS_STILL_BROKEN
+
+#ifdef SDL_WINDOW_FULLSCREEN_DESKTOP_IS_STILL_BROKEN
+        SDL_DisplayMode dm;
+
+        if (SDL_GetDesktopDisplayMode(0, &dm) == 0)
+        {
+            cx = dm.w;
+            cy = dm.h;
+            PUtil::outLog() << "Desktop video mode resolution: " << cx << 'x' << cy << std::endl;
+        }
+        else
+        {
+            PUtil::outLog() << "SDL error, SDL_GetDesktopDisplayMode(): " << SDL_GetError() << std::endl;
+            cx = 800;
+            cy = 600;
+        }
+
+        screen = SDL_CreateWindow(apptitle.c_str(),
+            SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED,
+            cx, cy,
+            SDL_WINDOW_OPENGL | SDL_WINDOW_FULLSCREEN);
+#else
+        //
+        // NOTE:
+        //  This would be the "proper" way of doing things, but at the time of this
+        //  writing it only works reliably on Windows 7 using SDL2 version 2.0.5.
+        //
+        screen = SDL_CreateWindow(apptitle.c_str(),
+            SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED,
+            0, 0,
+            SDL_WINDOW_OPENGL | SDL_WINDOW_FULLSCREEN_DESKTOP);
+#endif
+    }
   
   if (!screen) {
     PUtil::outLog() << "Failed to create window or set video mode" << std::endl;
@@ -280,11 +305,27 @@ int PApp::run(int argc, char *argv[])
     PUtil::outLog() << "Try changing your video settings in trigger-rally.config" << std::endl;
     SDL_Quit();
     if (PHYSFS_deinit() == 0) {
-      PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+      PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
     return 1;
   }
   
+  context = SDL_GL_CreateContext(screen);
+  
+    if (context == NULL)
+    {
+        PUtil::outLog() << "Failed to create OpenGL context for game window\n";
+        PUtil::outLog() << "SDL error: " << SDL_GetError() << std::endl;
+        SDL_DestroyWindow(screen);
+        SDL_Quit();
+
+        if (PHYSFS_deinit() == 0)
+		{
+            PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
+		}
+        return 1;
+    }
+  
   sdl_mousemap = 0;
   
   sdl_joy.resize(SDL_NumJoysticks());
@@ -297,13 +338,15 @@ int PApp::run(int argc, char *argv[])
     sdl_joy[i].sdl_joystick = SDL_JoystickOpen(i);
     if (sdl_joy[i].sdl_joystick == nullptr) {
       PUtil::outLog() << "failed to open joystick" << std::endl;
+      SDL_GL_DeleteContext(context);
+      SDL_DestroyWindow(screen);
       SDL_Quit();
       if (PHYSFS_deinit() == 0) {
-        PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+        PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
       }
       return 1;
     }
-    sdl_joy[i].name = SDL_JoystickName(i);
+    sdl_joy[i].name = SDL_JoystickName(sdl_joy[i].sdl_joystick);
     sdl_joy[i].axis.resize(SDL_JoystickNumAxes(sdl_joy[i].sdl_joystick));
     for (unsigned int j=0; j<sdl_joy[i].axis.size(); j++)
       sdl_joy[i].axis[j] = ((float)SDL_JoystickGetAxis(sdl_joy[i].sdl_joystick, j) + 0.5f) / 32767.5f;
@@ -329,16 +372,18 @@ int PApp::run(int argc, char *argv[])
   SDL_JoystickEventState(SDL_ENABLE);
   
   int err = glewInit();
-  
+
   if (err != GLEW_OK) {
     PUtil::outLog() << "GLEW failed to initialise: " << glewGetErrorString(err) << std::endl;
+    SDL_GL_DeleteContext(context);
+    SDL_DestroyWindow(screen);
     SDL_Quit();
     if (PHYSFS_deinit() == 0) {
-      PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+      PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
     return 1;
   }
-  
+
   PUtil::outLog() << "GLEW initialized" << std::endl;
   
   PUtil::outLog() << "Graphics: " <<
@@ -389,12 +434,16 @@ int PApp::run(int argc, char *argv[])
       delete sslist.back();
       sslist.pop_back();
     }
-    
+
+    SDL_GL_DeleteContext(context);
+    SDL_DestroyWindow(screen);
     SDL_Quit();
+
     if (PHYSFS_deinit() == 0)
     {
-      PUtil::outLog () << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+      PUtil::outLog () << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
+
     return 1;
   }
 
@@ -413,20 +462,25 @@ int PApp::run(int argc, char *argv[])
       sslist.pop_back();
     }
 
+    SDL_GL_DeleteContext(context);
+    SDL_DestroyWindow(screen);
     SDL_Quit();
+
     if (PHYSFS_deinit() == 0) {
-      PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+      PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
     }
+
     return 1;
   }
 
   //SDL_ShowCursor(SDL_DISABLE);
   //SDL_WM_GrabInput(SDL_GRAB_ON);
-  SDL_WM_GrabInput(SDL_GRAB_OFF);
-  SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
+  //SDL_WM_GrabInput(SDL_GRAB_OFF);
+  //SDL_SetWindowGrab(screen, SDL_TRUE);
+  //SDL_EnableKeyRepeat(SDL_DEFAULT_REPEAT_DELAY, SDL_DEFAULT_REPEAT_INTERVAL);
   //SDL_EnableUNICODE(1);
 
-  sdl_keymap = SDL_GetKeyState(&sdl_numkeys);
+  sdl_keymap = SDL_GetKeyboardState(&sdl_numkeys);
 
   resize();
 
@@ -460,9 +514,12 @@ int PApp::run(int argc, char *argv[])
         break;
       */
 
+      // unavailable (and unneeded?) in SDL2
+#if 0
       case SDL_VIDEOEXPOSE:
         repaint = true;
         break;
+#endif
 
       case SDL_KEYDOWN:
       case SDL_KEYUP:
@@ -547,7 +604,7 @@ int PApp::run(int argc, char *argv[])
         
         render(0.0f);
         glFlush();
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
         
       case StereoQuadBuffer: // Hardware quad buffer stereo
@@ -560,7 +617,7 @@ int PApp::run(int argc, char *argv[])
         render(stereoEyeTranslation);
         glFlush();
         
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
         
       case StereoRedBlue: // Red-blue anaglyph stereo
@@ -578,7 +635,7 @@ int PApp::run(int argc, char *argv[])
         render(stereoEyeTranslation);
         glFlush();
         
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
         
       case StereoRedGreen: // Red-green anaglyph stereo
@@ -596,7 +653,7 @@ int PApp::run(int argc, char *argv[])
         render(stereoEyeTranslation);
         glFlush();
         
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
         
       case StereoRedCyan: // Red-cyan anaglyph stereo
@@ -609,7 +666,7 @@ int PApp::run(int argc, char *argv[])
         render(stereoEyeTranslation);
         glFlush();
         
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
         
       case StereoYellowBlue: // Yellow-blue anaglyph stereo
@@ -622,7 +679,7 @@ int PApp::run(int argc, char *argv[])
         render(stereoEyeTranslation);
         glFlush();
         
-        SDL_GL_SwapBuffers();
+        SDL_GL_SwapWindow(screen);
         break;
       }
       repaint = false;
@@ -648,12 +705,12 @@ int PApp::run(int argc, char *argv[])
         PUtil::outLog() << "Writing screenshot \"" << filename << "\"" << std::endl;
         PHYSFS_file* pfile = PHYSFS_openWrite(filename);
         if (pfile) {
-          PHYSFS_write(pfile, buff, sizeof (char), strlen(buff));
-          PHYSFS_write(pfile, data1, sizeof (char), cx*cy*3);
+          physfs_write(pfile, buff, sizeof(char), strlen(buff));
+          physfs_write(pfile, data1, sizeof(char), cx*cy*3);
           PHYSFS_close(pfile);
         } else {
           PUtil::outLog() << "Screenshot write failed" << std::endl;
-          PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+          PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
         }
         delete[] data1;
         screenshot_requested = false;
@@ -675,15 +732,18 @@ int PApp::run(int argc, char *argv[])
     sslist.pop_back();
   }
   
-  SDL_WM_GrabInput(SDL_GRAB_OFF);
+  //SDL_WM_GrabInput(SDL_GRAB_OFF);
+  //SDL_SetWindowGrab(screen, SDL_FALSE);
   SDL_ShowCursor(SDL_ENABLE);
   
-  SDL_Quit();
+    SDL_GL_DeleteContext(context);
+    SDL_DestroyWindow(screen);
+    SDL_Quit();
   
   best_times.savePlayer();
   
   if (PHYSFS_deinit() == 0) {
-    PUtil::outLog() << "PhysFS: " << PHYSFS_getLastError() << std::endl;
+    PUtil::outLog() << "PhysFS: " << physfs_getErrorString() << std::endl;
   }
   
   PUtil::outLog() << "Shutdown complete" << std::endl;
@@ -703,7 +763,7 @@ void PApp::drawModel(PModel &model)
 {
   for (std::vector<PMesh>::iterator mesh = model.mesh.begin();
     mesh != model.mesh.end();
-    mesh++) {
+    ++mesh) {
     if (!mesh->effect)
       mesh->effect = getSSEffect().loadEffect(mesh->fxname);
 
