@@ -240,7 +240,7 @@ void MainApp::renderStateLoading(float eyetranslation)
     // if aspect ratio is larger than 1:1
     if ((float)getWidth()/(float)getHeight() > 1.0f)
     {
-      
+
       // lower and upper offset based on aspect ratio
       float off_l = (1 - ((float)getHeight() / (float)getWidth())) / 2.f;
       float off_u = 1 - off_l;
@@ -261,7 +261,7 @@ void MainApp::renderStateLoading(float eyetranslation)
       glTexCoord2f(off_u,0.0f); glVertex2f(1.0f, -1.0f);
     }
     glEnd();
-    
+
     tex_loading_screen->bind();
 
     GLfloat logovratio = static_cast<float> (getWidth()) / getHeight();
@@ -336,6 +336,7 @@ const char *creditstext[] =
     "Farrer",
     "Andrei Bondor",
     "Nikolay Orlyuk",
+	"Emanuele Sorce",
     "",
     "New levels",
     "Tim Wintle",
@@ -423,7 +424,7 @@ void MainApp::renderStateEnd(float eyetranslation)
     }
     glEnd();
 
-    tex_fontDsmOutlined->bind();
+    tex_fontSourceCodeOutlined->bind();
 
     glMatrixMode(GL_PROJECTION);
     glPopMatrix();
@@ -638,7 +639,7 @@ glMatrixMode(GL_PROJECTION);
     // use the same colors as the menu
     const GuiWidgetColors gwc = gui.getColors();
 
-    tex_fontDsmShadowed->bind();
+    tex_fontSourceCodeShadowed->bind();
 
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     glDisable(GL_DEPTH_TEST);
@@ -670,14 +671,14 @@ glMatrixMode(GL_PROJECTION);
     glTranslatef(100.0f, 230.0f, 0.0f);
     glScalef(30.0f, 30.0f, 1.0f);
     glColor4f(gwc.header.x, gwc.header.y, gwc.header.z, gwc.header.w);
-    getSSRender().drawText(vtype->proper_name, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
+    getSSRender().drawText(vtype->proper_name.substr(0, 9), PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     glPushMatrix(); // 1
     glTranslatef(100.0f, 200.0f, 0.0f);
     glScalef(20.0f, 20.0f, 1.0f);
     glColor4f(gwc.strong.x, gwc.strong.y, gwc.strong.z, gwc.strong.w);
-    getSSRender().drawText(vtype->proper_class, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
+    getSSRender().drawText(vtype->proper_class.substr(0, 8), PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     glPushMatrix(); // 1
@@ -705,21 +706,21 @@ glMatrixMode(GL_PROJECTION);
     glTranslatef(500.0f, 110.0f, 0.0f);
     glScalef(20.0f, 20.0f, 1.0f);
     glColor4f(gwc.weak.x, gwc.weak.y, gwc.weak.z, gwc.weak.w);
-    getSSRender().drawText("Handling", PTEXT_HZA_RIGHT | PTEXT_VTA_CENTER);
+    getSSRender().drawText("Roadholding", PTEXT_HZA_RIGHT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     glPushMatrix(); // 1
     glTranslatef(520.0f, 230.0f, 0.0f);
     glScalef(30.0f, 30.0f, 1.0f);
     glColor4f(gwc.strong.x, gwc.strong.y, gwc.strong.z, gwc.strong.w);
-    getSSRender().drawText(vtype->pstat_weightkg, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
+    getSSRender().drawText(std::to_string(static_cast<int>(vtype->mass)), PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     glPushMatrix(); // 1
     glTranslatef(520.0f, 190.0f, 0.0f);
     glScalef(30.0f, 30.0f, 1.0f);
     glColor4f(gwc.strong.x, gwc.strong.y, gwc.strong.z, gwc.strong.w);
-    getSSRender().drawText(vtype->pstat_enginebhp, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
+    getSSRender().drawText(vtype->pstat_enginepower, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     glPushMatrix(); // 1
@@ -733,7 +734,7 @@ glMatrixMode(GL_PROJECTION);
     glTranslatef(520.0f, 110.0f, 0.0f);
     glScalef(30.0f, 30.0f, 1.0f);
     glColor4f(gwc.strong.x, gwc.strong.y, gwc.strong.z, gwc.strong.w);
-    getSSRender().drawText(vtype->pstat_handling, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
+    getSSRender().drawText(vtype->pstat_roadholding, PTEXT_HZA_LEFT | PTEXT_VTA_CENTER);
     glPopMatrix(); // 1
 
     std::string racename;
@@ -1435,7 +1436,7 @@ void MainApp::renderStateGame(float eyetranslation)
       glPopMatrix(); // 2
       */
 
-      tex_fontDsmOutlined->bind();
+      tex_fontSourceCodeOutlined->bind();
 
       // time counter
 
@@ -1450,7 +1451,7 @@ void MainApp::renderStateGame(float eyetranslation)
       glTranslatef( -hratio + hratio * (2.5f/50.f), vratio - vratio * (5.5f/50.f), 0.0f);
       glScalef(0.125f, 0.125f, 1.0f);
 
-      if (game->gamestate == GS_FINISHED)
+      if (game->gamestate == Gamestate::finished)
       {
           getSSRender().drawText(
               PUtil::formatTime(game->coursetime),
@@ -1486,7 +1487,7 @@ void MainApp::renderStateGame(float eyetranslation)
 
     {
         // show the time penalty if there is any
-        const float timepen = game->offroadtime_total * game->offroadtime_penalty_multiplier;
+        const float timepen = game->uservehicle->offroadtime_total * game->offroadtime_penalty_multiplier;
 
         // FIXME: why do glPushMatrix() and glPopMatrix() not work for me?
         if (timepen >= 0.1f)
@@ -1521,13 +1522,13 @@ void MainApp::renderStateGame(float eyetranslation)
           glTranslatef( hratio - hratio * (2.5f/50.f), vratio - vratio * (5.5f/50.f), 0.0f);
           glScalef(0.125f, 0.125f, 1.0f);
 
-            if (game->getFinishState() != GF_NOT_FINISHED)
+            if (game->getFinishState() != Gamefinish::not_finished)
                 getSSRender().drawText(totalcp + '/' + totalcp, PTEXT_HZA_RIGHT | PTEXT_VTA_TOP);
             else
                 getSSRender().drawText(nextcp + '/' + totalcp, PTEXT_HZA_RIGHT | PTEXT_VTA_TOP);
 
           // checkpoint label
-          
+
           //glPushMatrix(); // 3
           glTranslatef(0, 0.52f, 0.0f);
           glScalef(0.65f, 0.65f, 1.0f);
@@ -1548,7 +1549,7 @@ void MainApp::renderStateGame(float eyetranslation)
             glTranslatef( hratio - hratio * (2.5f/50.f), vratio - vratio * (5.5f/50.f) - 0.20f, 0.0f);
             glScalef(0.125f, 0.125f, 1.0f);
 
-            if (game->getFinishState() != GF_NOT_FINISHED)
+            if (game->getFinishState() != Gamefinish::not_finished)
                 getSSRender().drawText(number_of_laps + '/' + number_of_laps, PTEXT_HZA_RIGHT | PTEXT_VTA_TOP);
             else
                 getSSRender().drawText(currentlap + '/' + number_of_laps, PTEXT_HZA_RIGHT | PTEXT_VTA_TOP);
@@ -1575,7 +1576,7 @@ void MainApp::renderStateGame(float eyetranslation)
 
         glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
 
-      tex_fontDsmNormal->bind();
+      tex_fontSourceCodeBold->bind();
 
       // show current gear and speed
       {
@@ -1626,14 +1627,14 @@ void MainApp::renderStateGame(float eyetranslation)
     glScalef(0.1f, 0.1f, 1.0f);
     glTranslatef(0.0f, -4.0f, 0.0f);
     glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
-    tex_fontDsmOutlined->bind();
+    tex_fontSourceCodeOutlined->bind();
     getSSRender().drawText(std::string("true time penalty: ") +
         std::to_string(game->offroadtime_total * game->offroadtime_penalty_multiplier),
         PTEXT_HZA_CENTER | PTEXT_VTA_TOP);
     glPopMatrix();
 #endif
 
-    tex_fontDsmShadowed->bind();
+    tex_fontSourceCodeShadowed->bind();
 
     // draw "off road" warning sign and text
     if (game->isRacing())
@@ -1663,7 +1664,7 @@ void MainApp::renderStateGame(float eyetranslation)
             glScalef(0.1f, 0.1f, 1.0f);
             glTranslatef(0.0f, -2.5f, 0.0f);
             glColor4f(1.0f, 1.0f, 0.0f, 1.0f);
-            tex_fontDsmOutlined->bind();
+            tex_fontSourceCodeOutlined->bind();
             getSSRender().drawText(
                 std::to_string(static_cast<int> (game->getOffroadTime() * game->offroadtime_penalty_multiplier)) +
                 " seconds",
@@ -1702,7 +1703,7 @@ void MainApp::renderStateGame(float eyetranslation)
             glEnable(GL_TEXTURE_2D);
             glPopMatrix();
         }
-        
+
         glColor3f(1.0f, 1.0f, 1.0f);
         getSSRender().drawText(s, PTEXT_HZA_CENTER | PTEXT_VTA_TOP);
         glPopMatrix(); // 2
@@ -1752,13 +1753,13 @@ void MainApp::renderStateGame(float eyetranslation)
     }
     #endif
 
-      tex_fontDsmOutlined->bind();
+      tex_fontSourceCodeOutlined->bind();
 
       glColor4f(1.0f, 0.0f, 0.0f, 1.0f);
       glPushMatrix(); // 2
       glTranslatef(0.0f, 0.2f, 0.0f);
       glScalef(0.6f, 0.6f, 1.0f);
-      if (game->gamestate == GS_COUNTDOWN)
+      if (game->gamestate == Gamestate::countdown)
       {
           float sizer = fmodf(game->othertime, 1.0f) + 0.5f;
           glScalef(sizer, sizer, 1.0f);
@@ -1766,9 +1767,9 @@ void MainApp::renderStateGame(float eyetranslation)
               PUtil::formatInt(((int)game->othertime + 1), 1),
               PTEXT_HZA_CENTER | PTEXT_VTA_CENTER);
       }
-      else if (game->gamestate == GS_FINISHED)
+      else if (game->gamestate == Gamestate::finished)
       {
-          if (game->getFinishState() == GF_PASS)
+          if (game->getFinishState() == Gamefinish::pass)
           {
               glColor4f(0.5f, 1.0f, 0.5f, 1.0f);
               getSSRender().drawText("WIN", PTEXT_HZA_CENTER | PTEXT_VTA_CENTER);
@@ -1793,7 +1794,7 @@ void MainApp::renderStateGame(float eyetranslation)
       }
       glPopMatrix(); // 2
 
-      if (game->gamestate == GS_COUNTDOWN)
+      if (game->gamestate == Gamestate::countdown)
       {
           glPushMatrix(); // 2
           glTranslatef(0.0f, 0.6f, 0.0f);
@@ -1835,4 +1836,3 @@ void MainApp::renderStateGame(float eyetranslation)
     glEnable(GL_DEPTH_TEST);
     glEnable(GL_LIGHTING);
 }
-
